<?xml version="1.0" encoding="iso-8859-1"?>
<!DOCTYPE xsl:stylesheet [<!ENTITY nbsp "&#160;"> ]>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

  <xsl:import href="page.xsl"/>

  <xsl:output method="html" encoding="iso-8859-1" doctype-public="-//W3C//DTD HTML 4.01//EN"/>
  <xsl:strip-space elements="*"/>


  <xsl:template match="entries">
    <html>
      <xsl:call-template name="make-head"/>
      <xsl:call-template name="make-body"/>
    </html>
  </xsl:template>


  <!-- Process contents, but with sorted entries -->
  <xsl:template name="process-content">
    <xsl:variable name="lower">abcdefghijklmnopqrstuvwxyz</xsl:variable>
    <xsl:variable name="upper">ABCDEFGHIJKLMNOPQRSTUVWXYZ</xsl:variable>
    <xsl:apply-templates select="entry">
      <!-- Hackeridoo! Force case-insensitive sorting -->
      <xsl:sort select="translate(@name, $lower, $upper)"/>
    </xsl:apply-templates>
  </xsl:template>

  <xsl:template name="firstblock">
    <xsl:variable name="blocks" select="*[name() != 'headline' and name() != 'nb']"/>
    <xsl:apply-templates select="$blocks[1]"/>
  </xsl:template>

  <xsl:template match="entry[@display]">
    <xsl:variable name="id" select="generate-id()"/>
    <h3>
      <a name="{$id}"/>
      <xsl:value-of select="@display"/>
      <xsl:apply-templates select="nb"/>
      <xsl:apply-templates select="@workinprogress"/>
    </h3>
    <xsl:call-template name="firstblock"/>
  </xsl:template>

  <xsl:template match="entry[headline]">
    <xsl:variable name="id" select="generate-id()"/>
    <h3>
      <a name="{$id}"/>
      <xsl:apply-templates select="headline"/>
      <xsl:apply-templates select="@workinprogress"/>
    </h3>
    <xsl:call-template name="firstblock"/>
  </xsl:template>

  <xsl:template match="entry">
    <xsl:variable name="id" select="generate-id()"/>
    <h3>
      <a name="{$id}"/>
      <xsl:value-of select="@name"/>
      <xsl:apply-templates select="nb"/>
      <xsl:apply-templates select="@workinprogress|@wanted"/>
    </h3>
    <xsl:call-template name="firstblock"/>
  </xsl:template>


  <xsl:template match="entry/@workinprogress[.]">
    <span style="color:black;font-size:smaller;font-weight:normal">
      (In Arbeit)
    </span>
  </xsl:template>


  <xsl:template match="entry/@wanted[.]">
    <span style="color:black;font-size:smaller;font-weight:normal">
      (Beitrge erwnscht)
    </span>
  </xsl:template>


  <xsl:template match="entry/nb|entry/headline/nb">
    <span style="color:black;font-size:smaller;font-weight:normal">
      [<xsl:apply-templates/>]
    </span>
  </xsl:template>

  <xsl:template match="nb">
    [<xsl:apply-templates/>]
  </xsl:template>

  <xsl:template match="entry/headline">
    <xsl:apply-templates/>
  </xsl:template>

  <!-- Special entry handling for references within lexicon -->
  <!-- Note: I'd like to simplify this by testing for "internal" links and -->
  <!-- Then using xsl:apply-imports, but xsltproc seems to fail on this -->
  <xsl:template match="see[text() and not(contains(@target, ':'))]">
    <xsl:variable name="p-entry" select="ancestor::entries/entry[./@name=current()/@target]"/>
    <xsl:variable name="newtarget" select="concat(generate-id($p-entry), '.html')"/>
    <xsl:call-template name="make-link">
      <xsl:with-param name="target" select="$newtarget"/>
      <xsl:with-param name="text" select="normalize-space(text())"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="see[not(contains(@target, ':'))]">
    <xsl:variable name="p-entry" select="ancestor::entries/entry[./@name=current()/@target]"/>
    <xsl:variable name="newtarget" select="concat(generate-id($p-entry), '.html')"/>
    <xsl:call-template name="make-link">
      <xsl:with-param name="target" select="$newtarget"/>
      <xsl:with-param name="text" select="@target"/>
    </xsl:call-template>
  </xsl:template>

</xsl:stylesheet>
