<?xml version="1.0" encoding="iso-8859-1"?>
<!DOCTYPE xsl:stylesheet [<!ENTITY nbsp "&#160;"> ]>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

  <xsl:import href="page.xsl"/>

  <xsl:output method="html" encoding="iso-8859-1" doctype-public="-//W3C//DTD HTML 4.01//EN"/>
  <xsl:strip-space elements="*"/>

  <xsl:template match="members">
    <table border="1" cellpadding="2" cellspacing="0" summary="Mitglieder der DDML">
      <colgroup span="7"/>
      <tr>
	<td colspan="7" align="center">
	  Postleitzahlenbereiche
	  <xsl:for-each select="member">
	    <xsl:sort select="country" lang="de" data-type="text"/>
	    <xsl:sort select="zip" lang="de" data-type="number"/>
	    <xsl:sort select="city" lang="de" data-type="text"/>
	    <xsl:sort select="name" lang="de" data-type="text"/>
	    <xsl:call-template name="linkifzipchange"/>
	    <xsl:call-template name="linkifcountrychange"/>
	  </xsl:for-each>
	</td>
      </tr>
      <tr>
	<th>Name</th>
	<th>PLZ/Ort</th>
	<th>Beruf</th>
	<th>Seit</th>
	<th>Bild</th>
	<th>Baujahr</th>
	<th>Homepage</th>
      </tr>
      <xsl:apply-templates select="member">
	<xsl:sort select="country" lang="de" data-type="text"/>
	<xsl:sort select="zip" lang="de" data-type="number"/>
	<xsl:sort select="city" lang="de" data-type="text"/>
	<xsl:sort select="name" lang="de" data-type="text"/>
      </xsl:apply-templates>
      <tr>
	<td colspan="7" align="center">
	  Postleitzahlenbereiche
	  <xsl:for-each select="member">
	    <xsl:call-template name="linkifzipchange"/>
	    <xsl:call-template name="linkifcountrychange"/>
	  </xsl:for-each>
	</td>
      </tr>
    </table>
  </xsl:template>


  <xsl:template match="member/name">
    <xsl:value-of select="."/>
  </xsl:template>

  <xsl:template name="mailurl">
    <!-- Assemble name and mail. If mail is defined, a `mailto:' URI is
	 generated.
    -->
    <xsl:choose>
      <xsl:when test="mail">
	<xsl:element name="a">
	  <xsl:attribute name="href">
	    <xsl:value-of select="concat('mailto:', mail)"/>
	  </xsl:attribute>
	  <xsl:attribute name="class">mail</xsl:attribute>
	  <xsl:apply-templates select="name"/>
	</xsl:element>
      </xsl:when>
      <xsl:otherwise>
	<xsl:apply-templates select="name"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>


  <xsl:template name="zipcity">
    <!-- If zip code and city are supplied, put both into the same cell,
	 separated by a break.
    -->
    <xsl:choose>
      <xsl:when test="zip and city">
	<xsl:value-of select="zip"/>
	<!-- <br/> -->
	<xsl:text> </xsl:text>
	<xsl:value-of select="city"/>
      </xsl:when>
      <xsl:otherwise>
	<xsl:value-of select="zip"/>
	<xsl:value-of select="city"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>


  <xsl:template name="jobs">
    <xsl:choose>
      <xsl:when test="job">
	<xsl:value-of select="job"/>
      </xsl:when>
      <xsl:when test="jobs">
	<xsl:for-each select="jobs/job">
	    <xsl:if test="position() != 1">
		<br/>
	    </xsl:if>
	    <xsl:value-of select="."/>
	</xsl:for-each>
      </xsl:when>
      <xsl:otherwise>&nbsp;</xsl:otherwise>
    </xsl:choose>
  </xsl:template>


  <xsl:template name="picture">
    <xsl:choose>
      <xsl:when test="picture">
	<xsl:element name="a">
	  <xsl:attribute name="href">
	      <xsl:choose>
		<xsl:when test="starts-with(picture, 'http:')">
		  <xsl:value-of select="picture"/>
		</xsl:when>
		<xsl:otherwise>
		  <xsl:value-of select="concat('members/', picture)"/>
		</xsl:otherwise>
	      </xsl:choose>
	  </xsl:attribute>
	  <xsl:attribute name="class">picture</xsl:attribute>
	  Ja
	</xsl:element>
      </xsl:when>
      <xsl:otherwise>&nbsp;</xsl:otherwise>
    </xsl:choose>
  </xsl:template>


  <xsl:template name="urls">
    <xsl:choose>
      <xsl:when test="url">
	<xsl:element name="a">
	  <xsl:attribute name="href">
	      <xsl:value-of select="url"/>
	  </xsl:attribute>
	  <xsl:attribute name="class">url</xsl:attribute>
	  Ja
	</xsl:element>
      </xsl:when>
      <xsl:when test="urls">
	<xsl:for-each select="urls/url">
	  <xsl:if test="position() != 1">
	    <br/>
	  </xsl:if>
	  <xsl:element name="a">
	    <xsl:attribute name="href">
	      <xsl:value-of select="."/>
	    </xsl:attribute>
	    <xsl:attribute name="class">url</xsl:attribute>
	    Ja <xsl:value-of select="concat('(', position(), ')')"/>
	  </xsl:element>
	</xsl:for-each>
      </xsl:when>
      <xsl:otherwise>&nbsp;</xsl:otherwise>
    </xsl:choose>
  </xsl:template>


  <xsl:template name="linkifzipchange">
    <xsl:if test="country = 'Deutschland'">
      <xsl:variable name="thiszipdigit" select="substring(zip, 1, 1)"/>
      <xsl:variable name="previouszipdigit" select="substring(preceding::zip[1], 1, 1)"/>
      <xsl:if test="$thiszipdigit != $previouszipdigit">
	<xsl:text> </xsl:text>
	<a href="#{generate-id(.)}">
	  <xsl:value-of select="$thiszipdigit"/>
	</a>
      </xsl:if>
    </xsl:if>
  </xsl:template>


  <xsl:template name="insertifzipchange">
    <xsl:if test="country = 'Deutschland'">
      <xsl:variable name="thiszipdigit" select="substring(zip, 1, 1)"/>
      <xsl:variable name="previouszipdigit" select="substring(preceding::zip[1], 1, 1)"/>
      <xsl:if test="$thiszipdigit != $previouszipdigit">
	<tr>
	  <td colspan="7" align="center">
	    <a name="{generate-id(.)}">
	      Bereich <xsl:value-of select="concat($thiszipdigit, '0000')"/>
	    </a>
	  </td>
	</tr>
      </xsl:if>
    </xsl:if>
  </xsl:template>


  <xsl:template name="linkifcountrychange">
    <xsl:variable name="thiscountry" select="country"/>
    <xsl:variable name="previouscountry" select="preceding::country[1]"/>
    <xsl:if test="$thiscountry != $previouscountry">
      <xsl:text> </xsl:text>
      <a href="#{generate-id(.)}">
	<xsl:value-of select="$thiscountry"/>
      </a>
    </xsl:if>
  </xsl:template>


  <xsl:template name="insertifcountrychange">
    <xsl:variable name="thiscountry" select="country"/>
    <xsl:variable name="previouscountry" select="preceding::country[1]"/>
    <xsl:if test="$thiscountry != $previouscountry">
      <tr>
	<td colspan="7" align="center">
	  <a name="{generate-id(.)}">
	    <xsl:value-of select="$thiscountry"/>
	  </a>
	</td>
      </tr>
    </xsl:if>
  </xsl:template>


  <xsl:template match="member">
    <xsl:call-template name="insertifzipchange"/>
    <xsl:call-template name="insertifcountrychange"/>
    <tr>
      <td>
	<xsl:call-template name="mailurl"/>
      </td>
      <td>
	<xsl:call-template name="zipcity"/>
      </td>
      <td>
	<xsl:call-template name="jobs"/>
      </td>
      <td>
	<xsl:value-of select="since"/>
      </td>
      <td>
	<xsl:call-template name="picture"/>
      </td>
      <td>
	<xsl:value-of select="birthday"/>
      </td>
      <td>
	<xsl:call-template name="urls"/>
      </td>
    </tr>
  </xsl:template>

</xsl:stylesheet>
