<?xml version="1.0" encoding="iso-8859-1"?>
<!DOCTYPE xsl:stylesheet [<!ENTITY nbsp "&#160;"> ]>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">

  <xsl:import href="config.xsl"/>

  <xsl:output method="html" encoding="iso-8859-1"/>
  <xsl:strip-space elements="*"/>


  <!-- Ignore text and unrecognized elements by default -->
  <xsl:template match="*|text()"/>


  <xsl:template name="findbase">
    <xsl:param name="prefix"/>
    <xsl:param name="menu" select="document('menu.xml', .)"/>
    <xsl:choose>
      <xsl:when test="$menu/menu/@top">
	<xsl:value-of select="$prefix"/>
      </xsl:when>
      <xsl:otherwise>
	<xsl:call-template name="findbase">
	  <xsl:with-param name="prefix" select="concat('../', $prefix)"/>
	  <xsl:with-param name="menu" select="document('../menu.xml', $menu)"/>
	</xsl:call-template>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>


  <xsl:variable name="base">
    <xsl:call-template name="findbase"/>
  </xsl:variable>

  <!-- Currently active menu. -->
  <xsl:variable name="menu" select="document('menu.xml', .)/menu"/>


  <!-- Background of first entry in currently active menu group -->
  <!-- We use the background color of the first entry of the menu, -->
  <!-- or the background color of the whole menu, if the first entry -->
  <!-- doesn't carry a background color. -->
  <xsl:variable name="background-color">
    <xsl:variable name="bg-1" select="$menu/*[1]/@background-color"/>
    <xsl:variable name="bg-m" select="$menu/@background-color"/>
    <xsl:value-of select="$bg-1 | $bg-m"/>
  </xsl:variable>


  <!-- Foregroundcolor for page title etc. Got from the title foreground of -->
  <!-- currently active menu group. -->
  <xsl:variable name="color">
    <xsl:value-of select="$menu/@color"/>
  </xsl:variable>


  <!-- Color for use in title banner. -->
  <!-- Either menu attribute @title-color, fallback $color -->
  <xsl:variable name="title-color">
    <xsl:choose>
      <xsl:when test="$menu/@title-color">
	<xsl:value-of select="$menu/@title-color"/>
      </xsl:when>
      <xsl:otherwise>
	<xsl:value-of select="$menu/@color"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:variable>


  <!-- The following three templates search the toplevel menu, constructing 
       a relative prefix to the root of the homepage
  -->
  <xsl:template match="/">
    <xsl:param name="prefix"/>
    <xsl:param name="current-page"/>
    <xsl:apply-templates>
      <xsl:with-param name="prefix" select="$prefix"/>
      <xsl:with-param name="current-page" select="$current-page"/>
    </xsl:apply-templates>
  </xsl:template>


  <xsl:template match="menu">
    <xsl:param name="prefix"/>
    <xsl:param name="current-page"/>
    <!-- Inner menu, proceed. -->
    <xsl:apply-templates select="document('../menu.xml', .)">
      <xsl:with-param name="prefix" select="concat('../', $prefix)"/>
      <xsl:with-param name="current-page" select="$current-page"/>
    </xsl:apply-templates>
  </xsl:template>


  <xsl:template match="menu[@top]">
    <xsl:param name="prefix"/>
    <xsl:param name="current-page"/>
    <!-- Found toplevel menu. Here we "go" -->
    <table border="{$tblborder}" cellpadding="0" cellspacing="0"
	   style="color:white;font-weight:bold"
	   summary="menu table abused for layout">
      <xsl:apply-templates mode="go" select=".">
	<xsl:with-param name="prefix" select="$prefix"/>
	<xsl:with-param name="current-page" select="$current-page"/>
      </xsl:apply-templates>
    </table>
  </xsl:template>



  <!-- Pass mode and params to child elements -->
  <xsl:template match="*|/" mode="go">
    <xsl:param name="prefix"/>
    <xsl:param name="level" select="number('1')"/>
    <xsl:param name="current-page"/>
    <xsl:apply-templates mode="go">
      <xsl:with-param name="prefix" select="$prefix"/>
      <xsl:with-param name="level" select="$level"/>
      <xsl:with-param name="current-page" select="$current-page"/>
    </xsl:apply-templates>
  </xsl:template>


  <!-- Ignore any text nodes -->
  <xsl:template match="text()" mode="go"/>


  <!-- Process nested submenus -->
  <xsl:template match="menu/menu" mode="go">
    <xsl:param name="prefix"/>
    <xsl:param name="level"/>
    <xsl:param name="current-page"/>
    <xsl:for-each select="@location">
      <xsl:variable name="submenuurl" select="concat(., '/menu.xml')"/>
      <xsl:variable name="submenu" select="document($submenuurl, .)"/>
      <xsl:variable name="subtitle" select="$submenu/menu/@title"/>
      <xsl:variable name="bg" select="$submenu/menu/@background-color"/>
      <xsl:variable name="fg" select="$submenu/menu/@color"/>
      <tr style="color:{$fg};background-color:{$bg}">
	<td class="leftfiller">&nbsp;</td>	<!-- left spacing column -->
	<td style="white-space:nowrap;padding-left:{($level - 1) * 0.5}em;padding-right:0">
	  <xsl:value-of select="$subtitle"/>
	</td>
	<td class="rightfiller" style="background-color:white">&nbsp;</td>
      </tr>
      <xsl:apply-templates mode="go" select="$submenu">
	<xsl:with-param name="prefix" select="concat($prefix, ., '/')"/>
	<xsl:with-param name="level" select="$level + 1"/>
	<xsl:with-param name="current-page" select="$current-page"/>
      </xsl:apply-templates>
    </xsl:for-each>
  </xsl:template>

  <!-- Create anchors for pagerefs -->
  <xsl:template match="menu/pageref" mode="go">
    <xsl:param name="prefix"/>
    <xsl:param name="level"/>
    <xsl:param name="current-page"/>
    <xsl:variable name="url" select="concat($prefix, @location, '.html')"/>
    <xsl:variable name="doc" select="document(concat(@location, '.xml'), .)"/>
    <xsl:variable name="fg" select="@color"/>
    <xsl:variable name="bg" select="@background-color"/>
    <xsl:variable name="tt" select="$doc/page/tooltip"/>
    <xsl:variable name="id" select="generate-id()"/>
    <xsl:variable name="filler-bg">
      <xsl:choose>
	<!-- We use the unique id to compare both nodesets -->
	<xsl:when test="generate-id($doc) = generate-id($current-page)">
	  <xsl:value-of select="$bg"/>
	</xsl:when>
	<xsl:otherwise>white</xsl:otherwise>
      </xsl:choose>
    </xsl:variable>
    <tr style="color:{$fg};background-color:{$bg}">
      <td class="leftfiller">&nbsp;</td>	<!-- left spacing column -->
      <td style="white-space:nowrap;padding-left:{($level - 1) * 0.5}em;padding-right:0">
	<a href="{$url}" style="color:{$fg}" title="{$tt}"
	   onMouseOver="this.parentNode.nextSibling.style.backgroundColor = '#FF3606';"
	   onMouseOut="this.parentNode.nextSibling.style.backgroundColor = '{$filler-bg}';"
	>
	  <xsl:call-template name="makevbars">
	    <xsl:with-param name="count" select="$level - 1"/>
	  </xsl:call-template>
	  <!-- Note: Attribute order matters! -->
	  <xsl:value-of select="@title | @location"/>
	</a>
      </td>
      <td class="rightfiller" style="background-color:{$filler-bg}">&nbsp;</td>
    </tr>
  </xsl:template>


  <!-- Dummy entries (no link, no submenu, just text) -->
  <xsl:template match="menu/dummy" mode="go">
    <xsl:param name="level"/>
    <xsl:variable name="fg" select="@color"/>
    <xsl:variable name="bg" select="@background-color"/>
    <tr style="color:{$fg};background-color:{$bg}">
      <td class="leftfiller">&nbsp;</td>	<!-- left spacing column -->
      <td style="white-space:nowrap;padding-left:{($level - 1) * 0.5}em;padding-right:0">
	<xsl:choose>
	  <xsl:when test="text()">
	    <span style="color:{$bg}">
	      <xsl:call-template name="makevbars">
		<xsl:with-param name="count" select="$level - 1"/>
	      </xsl:call-template>
	    </span>
	    <xsl:value-of select="."/>
	  </xsl:when>
	  <xsl:otherwise>
	    &nbsp;
	  </xsl:otherwise>
	</xsl:choose>
      </td>
      <td class="rightfiller" style="background-color:white">&nbsp;</td>
    </tr>
  </xsl:template>


  <!-- create $count vertical bars -->
  <xsl:template name="makevbars">
    <xsl:param name="count" select="0"/>
    <xsl:if test="$count > 0">
      <xsl:call-template name="makevbars">
	<xsl:with-param name="count" select="$count - 1"/>
      </xsl:call-template>
      |
    </xsl:if>
  </xsl:template>

</xsl:stylesheet>
