<?xml version="1.0" encoding="iso-8859-1"?>
<!DOCTYPE xsl:stylesheet [
  <!ENTITY nbsp "&#160;">
  <!ENTITY forum "http://www.didgeridu.de">
]>
<xsl:stylesheet version="1.0"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
>

  <xsl:import href="menu.xsl"/>
  <xsl:import href="config.xsl"/>

  <xsl:output method="html" encoding="iso-8859-1" doctype-public="-//W3C//DTD HTML 4.01//EN"/>
  <xsl:strip-space elements="*"/>


  <!-- Create the whole page -->
  <xsl:template match="page">
    <html>
      <xsl:call-template name="make-head"/>
      <xsl:call-template name="make-body"/>
    </html>
  </xsl:template>


  <!-- Create the head section -->
  <xsl:template name="make-head">
    <head>
      <title><xsl:value-of select="name"/></title>
      <style type="text/css">
	body { margin:0pt; }
	* { font-family: sans-serif; font-size: 10pt; }
	h1, h2, h3, h4, h5, h6 {
	  color:<xsl:value-of select="$background-color"/>;
	}
	h1 { font-size: 16pt; font-weight: bold; }
	h2 { font-size: 14pt; font-weight: bold; }
	h3 { font-size: 12pt; font-weight: bold; }
	h4 { font-size: 11pt; font-weight: bold; }
	h5 { font-size: 10pt; font-weight: bold; }
	h6 { font-size: 9pt; font-weight: bold; }
	*.title {
	  color:<xsl:value-of select="$title-color"/>;
	  background-color:<xsl:value-of select="$background-color"/>;
	  font-weight:bold; text-align:center;
	  margin-top:0;
	}
	a {
	  color: <xsl:value-of select="$background-color"/>;
	  text-decoration: none!important;
	  font-size: inherit;
	}
	ol, ul { padding-left: 2em; }
	td.leftfiller { padding-left: <xsl:value-of select="$menu-lpad"/>; }
	td.rightfiller {
	  padding-left:<xsl:value-of select="$menu-hpad"/>;
	  padding-right:<xsl:value-of select="$menu-hpad"/>;
	  padding-top:<xsl:value-of select="$menu-vpad"/>;
	  padding-bottom:<xsl:value-of select="$menu-vpad"/>;
	}
	img { border: 0; padding: 0}
      </style>
    </head>
  </xsl:template>


  <!-- Process page contents -->
  <xsl:template name="process-content">
    <xsl:apply-templates/>
  </xsl:template>


  <!-- Create the complete body element, including menu, content and footer -->
  <xsl:template name="make-body">
    <body style="background-color:white">
      <xsl:call-template name="make-banner">
	<!--xsl:with-param name="style">position:fixed;top:0</xsl:with-param-->
      </xsl:call-template>
      <!--xsl:call-template name="make-banner">
	<xsl:with-param name="style">visibility:hidden</xsl:with-param>
      </xsl:call-template-->
      <table border="{$tblborder}"
	     cellpadding="0" cellspacing="0"
	     width="100%"
	     summary="main table abused for layout"
      >
	<colgroup>
	  <col/>			<!-- Menu column -->
	  <col/>			<!-- hor. spacing column -->
	  <col width="100%"/>		<!-- Content column -->
	  <col/>			<!-- hor. spacing column -->
	</colgroup>
	<tr>
	  <td align="left" valign="top">	<!-- menu -->
	    <xsl:apply-templates select="document('menu.xml', /)/menu">
	      <xsl:with-param name="current-page" select="/"/>
	    </xsl:apply-templates>
	  </td>
	  <td style="padding:{$menu-hpad}">&nbsp;</td>		<!-- spacing column -->
	  <td valign="top">
	    <xsl:call-template name="process-content"/>		<!-- page contents -->
	  </td>
	  <td style="padding:{$menu-hpad}">&nbsp;</td>		<!-- spacing column -->
	</tr>
      </table>
    <xsl:call-template name="make-footer"/>
    </body>
  </xsl:template>


  <!-- Create the banner line -->
  <xsl:template name="make-banner">
    <xsl:param name="style"/>
    <xsl:variable name="home" select="$base"/>
    <xsl:variable name="leftlogo" select="concat($base, 'images/atddml.jpg')"/>
    <xsl:variable name="leftlogo.w" select="180"/>
    <xsl:variable name="leftlogo.h" select="72"/>
    <xsl:variable name="midlogo" select="concat($base, 'images/head.jpg')"/>
    <xsl:variable name="midlogo.w" select="590"/>
    <xsl:variable name="midlogo.h" select="72"/>
    <xsl:variable name="rightlogo" select="concat($base, 'images/desert.jpg')"/>
    <xsl:variable name="rightlogo.w" select="58"/>
    <xsl:variable name="rightlogo.h" select="72"/>
    <xsl:variable name="logo" select="concat($base, 'images/logo.gif')"/>
    <xsl:variable name="logo.w" select="90"/>
    <xsl:variable name="logo.h" select="71"/>
    <table border="{$tblborder}" style="padding:0;margin:0;margin-bottom:{$menu-hpad};{$style}" cellpadding="0" cellspacing="0" width="100%" summary="table abused for banner line">
      <tr>
	<td>
	  <a href="{$home}" title="DDML Homepage">
	    <img src="{$leftlogo}" alt="DDML Logo" width="{$leftlogo.w}" height="{$leftlogo.h}"/>
	  </a>
	</td>
	<td><img src="{$midlogo}" alt="DDML Title" width="{$midlogo.w}" height="{$midlogo.h}"/></td>
	<td align="right" style="width:100%;background-image:url({$rightlogo});background-repeat:repeat-x">
	  <!-- Just a little experiment (transparent gif over bg-image) -->
	  <a href="{$home}" title="DDML Homepage">
	    <img src="{$logo}" alt="DDML Logo" width="{$logo.w}" height="{$logo.h}"/>
	  </a>
	</td>
      </tr>
    </table>
  </xsl:template>


  <!-- Create footer line -->
  <xsl:template name="make-footer">
    <xsl:variable name="icons" select="concat($base, 'images')"/>
    <table border='0' style="padding:{$menu-hpad}" width="100%" summary="Page footer table">
      <colgroup>
	<col/>
	<col/>
	<col width="100%"/>
      </colgroup>
      <tr>
	<td>
	  <a href="http://validator.w3.org/check/referer">
	    <img src="{$icons}/valid-html401.gif" alt="Valid HTML 4.01!" width="66" height="24"/>
	  </a>
	</td>
	<td>
	  <a href="http://jigsaw.w3.org/css-validator/check/referer">
	    <img src="{$icons}/vcss.gif" alt="Valid CSS!" width="66" height="24"/>
	  </a>
	</td>
	<td align="center" style="font-size:large;font-weight:bold">
	  Partnerseite: <a href="&forum;">Online-Didgeridoo-Forum</a>
	</td>
      </tr>
    </table>
  </xsl:template>


  <!-- Page title gets a special css-class -->
  <xsl:template match="page/title">
    <h1 class="title">
      <xsl:apply-templates/>
    </h1>
  </xsl:template>


  <xsl:template match="light">
    <span style="color:white;font-size:smaller">
      <xsl:apply-templates/>
    </span>
  </xsl:template>


  <xsl:template match="text()">
    <xsl:value-of select="."/>
  </xsl:template>


  <xsl:template match="section">
    <xsl:variable name="depth" select="count(ancestor-or-self::section)"/>
    <xsl:element name="{concat('h', 1 + $depth)}">
      <xsl:apply-templates select="." mode="anchor"/>
    </xsl:element>
    <xsl:apply-templates/>
  </xsl:template>

  <xsl:template mode="anchor" match="section[@id]">
    <a name="{@id}"><xsl:value-of select="title"/></a>
  </xsl:template>

  <xsl:template mode="anchor" match="section">
    <a name="{title}"><xsl:value-of select="title"/></a>
  </xsl:template>


  <xsl:template match="legalstuff">
    <div style="font-size:smaller">
      <xsl:apply-templates/>
    </div>
  </xsl:template>


  <xsl:template match="quote">
    <xsl:variable name="content">
      <xsl:apply-templates/>
    </xsl:variable>
    "<em><xsl:value-of select="normalize-space($content)"/></em>"
    <br/>
    <xsl:apply-templates select="source" mode="showsource"/>
  </xsl:template>

  <xsl:template match="source" mode="showsource">
    (Aus: <xsl:apply-templates/>)
  </xsl:template>


  <xsl:template match="red">
    <div style="font-size:smaller">
      [<xsl:apply-templates/> (Anm. d. Red.)]
    </div>
  </xsl:template>

  <xsl:template match="mailto">
    <xsl:variable name="subject">
      <xsl:if test="@subject">
	<xsl:value-of select="concat('?subject=', @subject)"/>
      </xsl:if>
    </xsl:variable>
    <xsl:variable name="body">
      <xsl:if test="@body">
	<xsl:value-of select="concat('?body=', @body)"/>
      </xsl:if>
    </xsl:variable>
    <xsl:variable name="separator">
      <xsl:if test="@subject and @body">
	<xsl:text>&amp;</xsl:text>
      </xsl:if>
    </xsl:variable>
    <xsl:variable name="target" select="concat('mailto:', @address, $subject, $separator, $body)"/>
    <xsl:variable name="text">
      <xsl:choose>
	<xsl:when test="text()">
	  <xsl:value-of select="."/>
	</xsl:when>
	<xsl:otherwise>
	  <xsl:value-of select="@address"/>
	</xsl:otherwise>
      </xsl:choose>
    </xsl:variable>
    <xsl:call-template name="make-link">
      <xsl:with-param name="target" select="normalize-space($target)"/>
      <xsl:with-param name="text" select="normalize-space($text)"/>
    </xsl:call-template>
  </xsl:template>

  <!-- Note: we use this for the `yidaki' entities only! -->
  <xsl:template match="u">
    <span style="text-decoration:underline"><xsl:apply-templates/></span>
  </xsl:template>


  <xsl:template name="make-link">
    <xsl:param name="target"/>
    <xsl:param name="text" select="$target"/>
    <xsl:variable name="sym">
      <xsl:choose>
	<xsl:when test="starts-with($target, 'ftp:')">*</xsl:when>
	<xsl:when test="starts-with($target, 'http:')">*</xsl:when>
	<xsl:when test="starts-with($target, 'mailto:')">&lt;</xsl:when>
	<xsl:otherwise>-&gt;</xsl:otherwise>
      </xsl:choose>
    </xsl:variable>
    <xsl:variable name="mys">
      <xsl:if test="starts-with($target, 'mailto:')">&gt;</xsl:if>
    </xsl:variable>
    <xsl:variable name="pre">
      <xsl:if test="not(starts-with($target, './') or contains($target, ':') or contains($target, '..') or contains($target, '.html'))">#</xsl:if>
    </xsl:variable>
    <a href="{concat($pre, $target)}"><xsl:value-of select="concat($sym, $text, $mys)"/></a>
  </xsl:template>


  <xsl:template match="see">
    <xsl:call-template name="make-link">
      <xsl:with-param name="target" select="@target"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="see[text()]">
    <xsl:call-template name="make-link">
      <xsl:with-param name="target" select="@target"/>
      <xsl:with-param name="text" select="normalize-space(text())"/>
    </xsl:call-template>
  </xsl:template>


  <xsl:template match="roles">
    <table border="0" width="80%" summary="Zustaendigkeiten">
      <xsl:apply-templates/>
    </table>
  </xsl:template>

  <xsl:template match="role">
    <tr>
      <td>
	<xsl:value-of select="subject"/>:
      </td>
      <td>
	<xsl:value-of select="name"/>
      </td>
      <td>
	<xsl:apply-templates select="mailto"/>
      </td>
    </tr>
  </xsl:template>


  <!-- Templates for events (page "Treffen") -->
  <xsl:template match="events">
    <xsl:apply-templates select="event"/>
    <hr/>
  </xsl:template>

  <xsl:template match="event">
    <hr/>
    <dl>
      <xsl:apply-templates select="event-date"/>
      <xsl:apply-templates select="event-location"/>
      <xsl:apply-templates select="who"/>
      <xsl:apply-templates select="description"/>
      <xsl:apply-templates select="sleep-in"/>
      <xsl:apply-templates select="contact"/>
      <xsl:apply-templates select="event-info"/>
    </dl>
  </xsl:template>

  <xsl:template match="event-date">
    <dt>Wann:</dt><dd><xsl:value-of select="."/></dd>
  </xsl:template>

  <xsl:template match="event-location">
    <dt>Wo:</dt><dd><xsl:value-of select="."/></dd>
  </xsl:template>

  <xsl:template match="who">
    <dt>Wer:</dt><dd><xsl:value-of select="."/></dd>
  </xsl:template>

  <xsl:template match="sleep-in">
    <dt>bernachtung:</dt><dd><xsl:value-of select="."/></dd>
  </xsl:template>

  <xsl:template match="description">
    <dt>Was:</dt><dd><xsl:apply-templates/></dd>
  </xsl:template>

  <xsl:template match="contact">
    <dt>Kontakt:</dt><dd><xsl:apply-templates/></dd>
  </xsl:template>

  <xsl:template match="event-info">
    <dt>Infos:</dt><dd><xsl:apply-templates/></dd>
  </xsl:template>

  <!-- Templates for commercial banner advertisements -->
  <xsl:template match="banners">
    <table style="padding:0;margin:0" border="1" summary="Bannerwerbung">
      <tr>
	<td style="background:#00ffbf" colspan="2" align="center">
	  <strong>Hier Euer Platz. Bei Bedarf wird mehr geschaffen.</strong>
	</td>
      </tr>
      <xsl:apply-templates/>
    </table>
  </xsl:template>

  <xsl:template match="banner">
    <tr>
      <td valign="top">
	<a href="{url}">
	  <xsl:apply-templates select="img"/>
	</a>
      </td>
      <xsl:apply-templates select="rightbanner"/>
    </tr>
  </xsl:template>
  
  <!-- This is a special hack for the didge-mag -->
  <xsl:template match="rightbanner">
    <td rowspan="{@rowspan}">
      <a href="{url}">
	<xsl:apply-templates select="img"/>
      </a>
    </td>
  </xsl:template>


  <xsl:template match="body">
    <xsl:apply-templates/>
  </xsl:template>


  <!-- Following elements are equally used in HTML -->
  <xsl:template match="ul|ol|li|br|p|pre|img|em|strong">
    <xsl:element name="{name(.)}">
      <xsl:for-each select="@*">
	<xsl:attribute name="{name(.)}">
	  <xsl:value-of select="."/>
	</xsl:attribute>
      </xsl:for-each>
      <xsl:apply-templates/>
    </xsl:element>
  </xsl:template>


  <!-- special treatment of li elements with @display attributes -->
  <xsl:template match="li[@display]">
    <li>
      <strong>
	<xsl:value-of select="@display"/>
      </strong>
      <br/>
      <xsl:apply-templates/>
    </li>
  </xsl:template>


</xsl:stylesheet>
